#!/bin/sh

echo "post-install"

# App Central extend timeout, but the timeout seems be counted from post-install, not pre-install, so move "docker pull" to post-install.

docker pull lscr.io/linuxserver/daapd:version-28.2

echo "Completed docker pull"


# From Owntone v28.1, config name MUST change to owntone.conf. Without setup password, it failed to connect the webUI.
# Assume that the users installed previous version (v27.4) will not change any config on the original "forked-daapd.conf", directly use new config.
if [ ! -e /share/Docker/OwnTone/config/owntone.conf ]; then
	mkdir /share/Docker/OwnTone
	mkdir /share/Docker/OwnTone/config
	cp -rf $APKG_PKG_DIR/conf/owntone.conf /share/Docker/OwnTone/config/
else
    # If any users just install this App recently, it may already auto-produce the owntone.conf with wrong settings, need to overwrite it.
	# The overwrite command should be removed from next update. (larger than v28.2.0.r02)
	cp -rf $APKG_PKG_DIR/conf/owntone.conf /share/Docker/OwnTone/config/
fi

# From Owntone v28.2, LinuxServer.io describe to add pipe name for spotify connect server. (on mounted folder of /music/spotify)
if [ ! -e /share/Music/spotify ]; then
	mkfifo /share/Music/spotify
fi

#Remove the old config file.
if [ -e /share/Docker/OwnTone/config/forked-daapd.conf ]; then
	rm -f /share/Docker/OwnTone/config/forked-daapd.conf
fi


CONTAINER_TEST=$(docker container ls -a | grep OwnTone | awk '{print $1}')

if [ ! -z $CONTAINER_TEST ]; then
	docker rm -f $CONTAINER_TEST
fi

C_UID=$(id -u admin)
ADMIN_GID=$(id -g admin)

docker create -i -t --name=OwnTone \
	--net=host \
	-e PUID=$C_UID -e PGID=$ADMIN_GID \
	-v /etc/localtime:/etc/localtime:ro \
	-v /share/Docker/OwnTone/config:/config:rw \
	-v /share/Music:/music:rw \
	--restart unless-stopped \
	lscr.io/linuxserver/daapd:version-28.2

docker start OwnTone


case "$APKG_PKG_STATUS" in
	install)
		;;
	upgrade)
		oldim=$(docker images | grep lscr.io/linuxserver/daapd | grep none | awk '{print $3}')
		echo $oldim
		
		if [ ! -z $oldim ]; then 
			docker rmi -f $oldim
		fi
		;;
	*)
		;;
esac

# The followings can be removed from next release.
imold=$(docker images | grep ghcr.io/linuxserver/daapd | grep latest | awk '{print $3}')
echo $imold
		
if [ ! -z $imold ]; then 
	docker rmi -f $imold
fi

exit 0
